import { GraphQLSchema, GraphQLFieldMap, GraphQLArgument, GraphQLFieldConfigArgumentMap, GraphQLObjectType, GraphQLObjectTypeConfig, GraphQLFieldConfigMap, GraphQLInputFieldConfigMap, GraphQLInterfaceType, GraphQLInterfaceTypeConfig, GraphQLUnionType, GraphQLUnionTypeConfig, GraphQLEnumType, GraphQLEnumTypeConfig, GraphQLScalarType, GraphQLScalarTypeConfig, GraphQLInputObjectType, GraphQLInputObjectTypeConfig, GraphQLDirective, GraphQLDirectiveConfig, GraphQLSchemaConfig, GraphQLNamedType, GraphQLField, GraphQLInputField, GraphQLInputFieldConfig, GraphQLInputFieldMap, GraphQLArgumentConfig, GraphQLFieldConfig, ObjectTypeExtensionNode, InterfaceTypeExtensionNode, UnionTypeExtensionNode, EnumTypeExtensionNode, InputObjectTypeExtensionNode, GraphQLScalarSerializer, GraphQLScalarValueParser, GraphQLScalarLiteralParser, ScalarTypeExtensionNode } from 'graphql';
export declare function schemaToConfig(schema: GraphQLSchema): GraphQLSchemaConfig;
declare type GraphQLObject = GraphQLSchema | GraphQLDirective | GraphQLNamedType | GraphQLInputField | GraphQLField<any, any>;
declare type GraphQLConfig<T> = T extends GraphQLSchema ? GraphQLSchemaConfig : T extends GraphQLDirective ? GraphQLDirectiveConfig : T extends GraphQLObjectType ? GraphQLObjectTypeConfig<any, any> & {
    interfaces: Array<GraphQLInterfaceType>;
    fields: GraphQLFieldConfigMap<any, any>;
    extensions?: Record<string, any>;
    extensionASTNodes: Array<ObjectTypeExtensionNode>;
} : T extends GraphQLInterfaceType ? GraphQLInterfaceTypeConfig<any, any> & {
    interfaces: Array<GraphQLInterfaceType>;
    fields: GraphQLFieldConfigMap<any, any>;
    extensions?: Record<string, any>;
    extensionASTNodes: Array<InterfaceTypeExtensionNode>;
} : T extends GraphQLUnionType ? GraphQLUnionTypeConfig<any, any> & {
    types: Array<GraphQLObjectType>;
    extensions?: Record<string, any>;
    extensionASTNodes: Array<UnionTypeExtensionNode>;
} : T extends GraphQLEnumType ? GraphQLEnumTypeConfig & {
    extensions?: Record<string, any>;
    extensionASTNodes: Array<EnumTypeExtensionNode>;
} : T extends GraphQLScalarType ? GraphQLScalarTypeConfig<any, any> & {
    serialize: GraphQLScalarSerializer<any>;
    parseValue: GraphQLScalarValueParser<any>;
    parseLiteral: GraphQLScalarLiteralParser<any>;
    extensions?: Record<string, any>;
    extensionASTNodes: Array<ScalarTypeExtensionNode>;
} : T extends GraphQLInputObjectType ? GraphQLInputObjectTypeConfig & {
    fields: GraphQLInputFieldConfigMap;
    extensions?: Record<string, any>;
    extensionASTNodes: Array<InputObjectTypeExtensionNode>;
} : T extends GraphQLField<any, any> ? GraphQLFieldConfig<any, any> & {} : T extends GraphQLInputField ? GraphQLInputFieldConfig : never;
export declare function toConfig(graphqlObject: GraphQLSchema): GraphQLConfig<GraphQLSchema>;
export declare function toConfig(graphqlObject: GraphQLDirective): GraphQLConfig<GraphQLDirective>;
export declare function toConfig(graphqlObject: GraphQLObjectType): GraphQLConfig<GraphQLObjectType>;
export declare function toConfig(graphqlObject: GraphQLInterfaceType): GraphQLConfig<GraphQLInterfaceType>;
export declare function toConfig(graphqlObject: GraphQLUnionType): GraphQLConfig<GraphQLUnionType>;
export declare function toConfig(graphqlObject: GraphQLEnumType): GraphQLConfig<GraphQLEnumType>;
export declare function toConfig(graphqlObject: GraphQLScalarType): GraphQLConfig<GraphQLScalarType>;
export declare function toConfig(graphqlObject: GraphQLInputObjectType): GraphQLConfig<GraphQLInputObjectType>;
export declare function toConfig(graphqlObject: GraphQLField<any, any>): GraphQLConfig<GraphQLField<any, any>>;
export declare function toConfig(graphqlObject: GraphQLInputField): GraphQLConfig<GraphQLInputField>;
export declare function toConfig<T extends GraphQLObject>(graphqlObject: T): GraphQLConfig<T>;
export declare function typeToConfig(type: GraphQLObjectType): GraphQLConfig<GraphQLObjectType>;
export declare function typeToConfig(type: GraphQLInterfaceType): GraphQLConfig<GraphQLInterfaceType>;
export declare function typeToConfig(type: GraphQLUnionType): GraphQLConfig<GraphQLUnionType>;
export declare function typeToConfig(type: GraphQLEnumType): GraphQLConfig<GraphQLEnumType>;
export declare function typeToConfig(type: GraphQLScalarType): GraphQLConfig<GraphQLScalarType>;
export declare function typeToConfig(type: GraphQLInputObjectType): GraphQLConfig<GraphQLInputObjectType>;
export declare function typeToConfig<T extends GraphQLNamedType>(type: T): GraphQLConfig<T>;
export declare function objectTypeToConfig(type: GraphQLObjectType): GraphQLObjectTypeConfig<any, any>;
export declare function interfaceTypeToConfig(type: GraphQLInterfaceType): GraphQLInterfaceTypeConfig<any, any>;
export declare function unionTypeToConfig(type: GraphQLUnionType): GraphQLUnionTypeConfig<any, any>;
export declare function enumTypeToConfig(type: GraphQLEnumType): GraphQLEnumTypeConfig;
export declare function scalarTypeToConfig(type: GraphQLScalarType): GraphQLScalarTypeConfig<any, any>;
export declare function inputObjectTypeToConfig(type: GraphQLInputObjectType): GraphQLInputObjectTypeConfig;
export declare function inputFieldMapToConfig(fields: GraphQLInputFieldMap): GraphQLInputFieldConfigMap;
export declare function inputFieldToConfig(field: GraphQLInputField): GraphQLInputFieldConfig;
export declare function directiveToConfig(directive: GraphQLDirective): GraphQLDirectiveConfig;
export declare function fieldMapToConfig(fields: GraphQLFieldMap<any, any>): GraphQLFieldConfigMap<any, any>;
export declare function fieldToConfig(field: GraphQLField<any, any>): GraphQLFieldConfig<any, any>;
export declare function argumentMapToConfig(args: ReadonlyArray<GraphQLArgument>): GraphQLFieldConfigArgumentMap;
export declare function argumentToConfig(arg: GraphQLArgument): GraphQLArgumentConfig;
export {};
